emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 9c86325: ; * lisp/progmodes/gdb-mi.el (gdb-mi-decod


From: Eli Zaretskii
Subject: [Emacs-diffs] master 9c86325: ; * lisp/progmodes/gdb-mi.el (gdb-mi-decode): Improve last change.
Date: Thu, 01 Oct 2015 11:53:09 +0000

branch: master
commit 9c86325b69d75e9b17ff468f5a2220597979635f
Author: Eli Zaretskii <address@hidden>
Commit: Eli Zaretskii <address@hidden>

    ; * lisp/progmodes/gdb-mi.el (gdb-mi-decode): Improve last change.
---
 lisp/progmodes/gdb-mi.el |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/lisp/progmodes/gdb-mi.el b/lisp/progmodes/gdb-mi.el
index 47589fb..4bee7c1 100644
--- a/lisp/progmodes/gdb-mi.el
+++ b/lisp/progmodes/gdb-mi.el
@@ -2359,11 +2359,11 @@ file names include non-ASCII characters."
              buffer-file-coding-system))))
     (with-temp-buffer
       (set-buffer-multibyte nil)
-      (insert (gdb-mi-quote string))
+      (prin1 string (current-buffer))
       (goto-char (point-min))
       ;; gdb-mi-quote quotes the octal escapes as well, which
       ;; interferes with their interpretation by 'read' below.  Remove
       ;; the extra backslashes to countermand that.
       (while (re-search-forward "\\\\\\(\\\\[2-3][0-7][0-7]\\)" nil t)
         (replace-match "\\1" nil nil))
       (goto-char (point-min))
@@ -2359,11 +2359,11 @@ file names include non-ASCII characters."
       (goto-char (point-min))
-      ;; gdb-mi-quote quotes the octal escapes as well, which
-      ;; interferes with their interpretation by 'read' below.  Remove
-      ;; the extra backslashes to countermand that.
+      ;; prin1 quotes the octal escapes as well, which interferes with
+      ;; their interpretation by 'read' below.  Remove the extra
+      ;; backslashes to countermand that.
       (while (re-search-forward "\\\\\\(\\\\[2-3][0-7][0-7]\\)" nil t)
         (replace-match "\\1" nil nil))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]